## 2.9.8 (2022-02-16)

Remove unused allowlist entries in `babel` and `requests` (#7233)

## 2.9.7 (2022-02-07)

Improve a bunch of `__(deep)copy__` methods (#7148)

## 2.9.6 (2022-01-28)

Add babel.core.get_global (#7063)

## 2.9.5 (2022-01-07)

Update pyright (#6840)

Improve Babel dates stub (#6730)

## 2.9.3 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.9.2 (2021-12-17)

Use stubtest 0.920 (#6589)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Sebastian Rittau <srittau@rittau.biz>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.9.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

